@@ -1,6 +1,6 @@
-from asyncio import Future, ensure_future, get_event_loop
+from asyncio import Future, ensure_future, get_event_loop, iscoroutinefunction
 from time import sleep
-from typing import Any, Callable, Dict, List, Type
+from typing import Any, Awaitable, Callable, Dict, List, Type
 
 from lime_python import (ClientChannel, Command, CommandMethod, Envelope,
                          GuestAuthentication, KeyAuthentication, Message,
@@ -8,8 +8,8 @@ from lime_python import (ClientChannel, Command, CommandMethod, Envelope,
                          Reason, ReasonCode, Session, SessionState, Transport)
 
 from .application import Application
-from .extensions import (AiExtension, ChatExtension, ExtensionBase,
-                         MediaExtension)
+from .extensions import (AIExtension, AnalyticsExtension, ChatExtension,
+                         ExtensionBase, MediaExtension)
 from .receiver import Receiver
 from .utilities import ClassUtilities
 
@@ -66,8 +66,15 @@ class Client:
         return self.__get_extension(MediaExtension, self.application.domain)
 
     @property
-    def ai_extension(self) -> AiExtension:  # noqa: D102
-        return self.__get_extension(AiExtension, self.application.domain)
+    def ai_extension(self) -> AIExtension:  # noqa: D102
+        return self.__get_extension(AIExtension, self.application.domain)
+
+    @property
+    def analytics_extension(self) -> AnalyticsExtension:  # noqa: D102
+        return self.__get_extension(
+            AnalyticsExtension,
+            self.application.domain
+        )
 
     @property
     def listening(self) -> bool:  # noqa: D102
@@ -216,8 +223,7 @@ class Client:
         Returns:
             Session: The connected Session
         """  # noqa: DAR402
-        loop = get_event_loop()
-        return loop.run_until_complete(self.connect_async())
+        return self.__run_async_on_sync(self.connect_async)
 
     def close(self) -> Session:
         """Close the open connection.
@@ -225,8 +231,7 @@ class Client:
         Returns:
             Session: the closed session
         """
-        loop = get_event_loop()
-        return loop.run_until_complete(self.close_async())
+        return self.__run_async_on_sync(self.close_async)
 
     def send_message(self, message: Message) -> None:
         """Send a Message.
@@ -286,9 +291,10 @@ class Client:
         Returns:
             Command: The result Command
         """
-        loop = get_event_loop()
-        return loop.run_until_complete(
-            self.process_command_async(command, timeout)
+        return self.__run_async_on_sync(
+            self.process_command_async,
+            command,
+            timeout
         )
 
     def add_message_receiver(self, receiver: Receiver) -> Callable[[], None]:
@@ -461,7 +467,7 @@ class Client:
         envelope: Envelope
     ) -> None:
         for handler in handler_list:
-            handler(envelope)
+            self.__ensure_run_action(handler, envelope)
 
     def __client_channel_on_command(
         self,
@@ -484,8 +490,8 @@ class Client:
         receiver_list: List[Receiver],
         envelope: Envelope
     ) -> None:
-        [   # noqa: WPS428
-            receiver.callback(envelope)
+        [  # noqa: WPS428
+            self.__ensure_run_action(receiver.callback, envelope)
             for receiver in receiver_list
             if receiver.predicate(envelope)
         ]
@@ -530,7 +536,7 @@ class Client:
         for receiver in self.__message_receivers:
             result: bool = None
             if receiver.predicate(message):
-                result = receiver.callback(message)
+                result = self.__ensure_run_action(receiver.callback, message)
             if result is False:
                 raise ValueError
 
@@ -573,3 +579,17 @@ class Client:
 
     def __reflect(self, any: Any) -> Any:
         return any
+
+    def __ensure_run_action(self, action_async: Awaitable, *args) -> Any:
+        if iscoroutinefunction(action_async):
+            loop = get_event_loop()
+            return loop.create_task(action_async(*args))
+        return action_async(*args)
+
+    def __run_async_on_sync(self, action_async: Awaitable, *args) -> Any:
+        loop = get_event_loop()
+        if loop.is_running():
+            raise ValueError(
+                'Cannot use sync method in async context, use the async version'  # noqa: E501
+            )
+        return loop.run_until_complete(action_async(*args))
