@@ -1,3 +1,3 @@
-from .ai_analytics_extension import AiAnalyticsExtension
+from .ai_analytics_extension import AIAnalyticsExtension
 from .content_type import ContentType
 from .uri_templates import UriTemplates
