@@ -1,3 +1,3 @@
-from .ai_model_extension import AiModelExtension
+from .ai_model_extension import AIModelExtension
 from .content_type import ContentType
 from .uri_templates import UriTemplates
